==> nextcloud-app-bookmarks-1:15.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/lt_LT.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Adresynas",
    "You deleted \"%s\"" : "Jūs ištrynėte \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ištrynė \"%2$s\"",
    "Someone deleted \"%s\"" : "Kažkas ištrynė \"%s\"",
    "You created folder \"%s\"" : "Jūs sukūrėte aplanką \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s sukūrė aplanką \"%2$s\"",
    "Someone created folder \"%s\"" : "Kažkas sukūrė aplanką \"%s\"",
    "You moved folder \"%s\"" : "Jūs perkėlėte aplanką \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s perkėlė aplanką \"%2$s\"",
    "Someone moved folder \"%s\"" : "Kažkas perkėlė aplanką \"%s\"",
    "You deleted folder \"%s\"" : "Jūs ištrynėte aplanką \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ištrynė aplanką \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Kažkas ištrynė aplanką \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Jūs pradėjote bendrinti aplanką „%1$s“ su %2$s",
    "No file provided for import" : "Importavimui nepateiktas joks failas",
    "Link copied to clipboard" : "Nuoroda nukopijuota į iškarpinę",
    "Select bookmark" : "Pasirinkti adresyno įrašą",
    "Details" : "Išsamiau",
    "Rename" : "Pervadinti",
    "Copy link" : "Kopijuoti nuorodą",
    "Move" : "Perkelti",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Pažymėtas %n adresyno įrašas","Pažymėti %n adresyno įrašai","Pažymėta %n adresyno įrašų","Pažymėtas %n adresyno įrašas"],
    "Move selection" : "Perkelti žymėjimą",
    "Delete selection" : "Ištrinti žymėjimą",
    "Select all" : "Pažymėti viską",
    "Sort by title" : "Rikiuoti pagal sąveiką",
    "RSS feed copied" : "RSS kanalas nukopijuotas",
    "Go back" : "Grįžti",
    "Share folder" : "Bendrinti aplanką",
    "Select one or more tags" : "Pasirinkite vieną ar daugiau žymų",
    "New" : "Nauja",
    "New folder" : "Naujas aplankas",
    "Change to grid view" : "Keisti į tinklelio rodinį",
    "Change to list view" : "Keisti į sąrašo rodinį",
    "Search" : "Ieškoti",
    "Empty trash bin" : "Išvalyti šiukšlinę",
    "Enter a link" : "Įveskite nuorodą",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankas"],
    "Add a bookmark" : "Pridėti adresyno įrašą",
    "Enter folder title" : "Įveskite aplanko pavadinimą",
    "Shared by {user}" : "Bendrina {user}",
    "Rename folder" : "Pervadinti aplanką",
    "Move folder" : "Perkelti aplanką",
    "Choose folder" : "Pasirinkti aplanką",
    "Submit" : "Pateikti",
    "Cancel" : "Atsisakyti",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Perkeliamas %n aplankas ir keli adresyno įrašai","Perkeliami %n aplankai ir keli adresyno įrašai","Perkeliama %n aplankų ir keli adresyno įrašai","Perkeliamas %n aplankas ir keli adresyno įrašai"],
    "_Moving %n folder_::_Moving %n folders_" : ["Perkeliamas %n aplankas","Perkeliami %n aplankai","Perkeliama %n aplankų","Perkeliamas %n aplankas"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Perkeliamas %n adresyno įrašas","Perkeliami %n adresyno įrašai","Perkeliama %n adresyno įrašų","Perkeliamas %n adresyno įrašas"],
    "Recent" : "Paskiausi",
    "Shared with you" : "Bendrinama su jumis",
    "Files" : "Failai",
    "New tag" : "Nauja žyma",
    "Delete" : "Ištrinti",
    "Untagged" : "Be žymų",
    "No bookmarks here" : "Čia adresyno įrašų nėra",
    "Client apps" : "Kliento programėlės",
    "Add to {instanceName}" : "Pridėti į {instanceName}",
    "Need help?" : "Reikia pagalbos?",
    "Title" : "Pareigos",
    "Link" : "Nuoroda",
    "Root folder" : "Šakninis aplankas",
    "Tags" : "Žymos",
    "Notes" : "Pastabos",
    "Download file" : "Atsisiųsti failą",
    "Link copied" : "Nuoroda nukopijuota",
    "Owner" : "Savininkas",
    "Sharing" : "Bendrinimas",
    "Select a user or group" : "Pasirinkti naudotoją ar grupę",
    "Share link" : "Viešinio nuoroda",
    "Copy RSS feed" : "Kopijuoti RSS kanalą",
    "Delete link" : "Ištrinti nuorodą",
    "Create public link" : "Sukurti viešąją nuorodą",
    "Allow editing" : "Leisti redaguoti",
    "Allow resharing" : "Leisti bendrinti iš naujo",
    "Remove share" : "Šalinti viešinį",
    "Failed to save settings" : "Nepavyko įrašyti nustatymų",
    "Failed to load settings" : "Nepavyko įkelti nustatymų",
    "Privacy" : "Privatumas",
    "Enable accessing and collecting information from the web pages you add" : "Leisti apsilankyti ir rinkti iš saityno informaciją apie jūsų pridedamus internetinius puslapius",
    "Performance" : "Našumas",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Didžiausias, vienai paskyrai leidžiamas, adresyno įrašų skaičius. (0, kad būtų neribojama; pagal numatymą yra neribojama)",
    "Previews" : "Peržiūros",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Galite arba nemokamai užsiregistruoti adresu screeenly.com, arba nusistatyti savo asmeninį serverį.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API raktas",
    "This URL is already bookmarked! Overwrite?" : "Šis URL jau įtrauktas į adresyną! Perrašyti?",
    "Enter bookmark title" : "Įveskite adresyno įrašo pavadinimą",
    "Enter bookmark URL" : "Įveskite adresyno įrašo URL",
    "Folder" : "Aplankas",
    "Save" : "Įrašyti",
    "What's new?" : "Kas naujo?",
    "Failed to find existing bookmark" : "Nepavyko rasti esamo adresyno įrašo",
    "Failed to create bookmark" : "Nepavyko sukurti adresyno įrašo",
    "Failed to save bookmark" : "Nepavyko įrašyti adresyno įrašo",
    "Failed to move bookmark" : "Nepavyko perkelti adresyno įrašo",
    "Failed to delete bookmark" : "Nepavyko ištrinti adresyno įrašo",
    "Failed to rename tag" : "Nepavyko pervadinti žymos",
    "Failed to load tags" : "Nepavyko įkelti žymų",
    "Failed to load folders" : "Nepavyko įkelti aplankų",
    "Failed to delete folder" : "Nepavyko ištrinti aplanko",
    "Failed to create folder" : "Nepavyko sukurti aplanko",
    "Failed to fetch bookmarks." : "Nepavyko gauti adresyno įrašų.",
    "Failed to load setting {key}" : "Nepavyko įkelti nustatymo {key}",
    "Failed to update share {shareId}" : "Nepavyko atnaujinti viešinio {shareId}",
    "Failed to delete share {shareId}" : "Nepavyko ištrinti viešinio {shareId}",
    "Bookmarks feed" : "Adresyno įrašų kanalas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-bookmarks-1:15.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/lt_LT.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Adresynas",
    "You deleted \"%s\"" : "Jūs ištrynėte \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ištrynė \"%2$s\"",
    "Someone deleted \"%s\"" : "Kažkas ištrynė \"%s\"",
    "You created folder \"%s\"" : "Jūs sukūrėte aplanką \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s sukūrė aplanką \"%2$s\"",
    "Someone created folder \"%s\"" : "Kažkas sukūrė aplanką \"%s\"",
    "You moved folder \"%s\"" : "Jūs perkėlėte aplanką \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s perkėlė aplanką \"%2$s\"",
    "Someone moved folder \"%s\"" : "Kažkas perkėlė aplanką \"%s\"",
    "You deleted folder \"%s\"" : "Jūs ištrynėte aplanką \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ištrynė aplanką \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Kažkas ištrynė aplanką \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Jūs pradėjote bendrinti aplanką „%1$s“ su %2$s",
    "No file provided for import" : "Importavimui nepateiktas joks failas",
    "Link copied to clipboard" : "Nuoroda nukopijuota į iškarpinę",
    "Select bookmark" : "Pasirinkti adresyno įrašą",
    "Details" : "Išsamiau",
    "Rename" : "Pervadinti",
    "Copy link" : "Kopijuoti nuorodą",
    "Move" : "Perkelti",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Pažymėtas %n adresyno įrašas","Pažymėti %n adresyno įrašai","Pažymėta %n adresyno įrašų","Pažymėtas %n adresyno įrašas"],
    "Move selection" : "Perkelti žymėjimą",
    "Delete selection" : "Ištrinti žymėjimą",
    "Select all" : "Pažymėti viską",
    "Sort by title" : "Rikiuoti pagal sąveiką",
    "RSS feed copied" : "RSS kanalas nukopijuotas",
    "Go back" : "Grįžti",
    "Share folder" : "Bendrinti aplanką",
    "Select one or more tags" : "Pasirinkite vieną ar daugiau žymų",
    "New" : "Nauja",
    "New folder" : "Naujas aplankas",
    "Change to grid view" : "Keisti į tinklelio rodinį",
    "Change to list view" : "Keisti į sąrašo rodinį",
    "Search" : "Ieškoti",
    "Empty trash bin" : "Išvalyti šiukšlinę",
    "Enter a link" : "Įveskite nuorodą",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankas"],
    "Add a bookmark" : "Pridėti adresyno įrašą",
    "Enter folder title" : "Įveskite aplanko pavadinimą",
    "Shared by {user}" : "Bendrina {user}",
    "Rename folder" : "Pervadinti aplanką",
    "Move folder" : "Perkelti aplanką",
    "Choose folder" : "Pasirinkti aplanką",
    "Submit" : "Pateikti",
    "Cancel" : "Atsisakyti",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Perkeliamas %n aplankas ir keli adresyno įrašai","Perkeliami %n aplankai ir keli adresyno įrašai","Perkeliama %n aplankų ir keli adresyno įrašai","Perkeliamas %n aplankas ir keli adresyno įrašai"],
    "_Moving %n folder_::_Moving %n folders_" : ["Perkeliamas %n aplankas","Perkeliami %n aplankai","Perkeliama %n aplankų","Perkeliamas %n aplankas"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Perkeliamas %n adresyno įrašas","Perkeliami %n adresyno įrašai","Perkeliama %n adresyno įrašų","Perkeliamas %n adresyno įrašas"],
    "Recent" : "Paskiausi",
    "Shared with you" : "Bendrinama su jumis",
    "Files" : "Failai",
    "New tag" : "Nauja žyma",
    "Delete" : "Ištrinti",
    "Untagged" : "Be žymų",
    "No bookmarks here" : "Čia adresyno įrašų nėra",
    "Client apps" : "Kliento programėlės",
    "Add to {instanceName}" : "Pridėti į {instanceName}",
    "Need help?" : "Reikia pagalbos?",
    "Created on {date}" : "Sukurta {date}",
    "Title" : "Pareigos",
    "Link" : "Nuoroda",
    "Root folder" : "Šakninis aplankas",
    "Tags" : "Žymos",
    "Notes" : "Pastabos",
    "Download file" : "Atsisiųsti failą",
    "Link copied" : "Nuoroda nukopijuota",
    "Owner" : "Savininkas",
    "Sharing" : "Bendrinimas",
    "Select a user or group" : "Pasirinkti naudotoją ar grupę",
    "Share link" : "Viešinio nuoroda",
    "Copy RSS feed" : "Kopijuoti RSS kanalą",
    "Delete link" : "Ištrinti nuorodą",
    "Create public link" : "Sukurti viešąją nuorodą",
    "Allow editing" : "Leisti redaguoti",
    "Allow resharing" : "Leisti bendrinti iš naujo",
    "Remove share" : "Šalinti viešinį",
    "Failed to save settings" : "Nepavyko įrašyti nustatymų",
    "Failed to load settings" : "Nepavyko įkelti nustatymų",
    "Privacy" : "Privatumas",
    "Enable accessing and collecting information from the web pages you add" : "Leisti apsilankyti ir rinkti iš saityno informaciją apie jūsų pridedamus internetinius puslapius",
    "Performance" : "Našumas",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Didžiausias, vienai paskyrai leidžiamas, adresyno įrašų skaičius. (0, kad būtų neribojama; pagal numatymą yra neribojama)",
    "Previews" : "Peržiūros",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Galite arba nemokamai užsiregistruoti adresu screeenly.com, arba nusistatyti savo asmeninį serverį.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API raktas",
    "This URL is already bookmarked! Overwrite?" : "Šis URL jau įtrauktas į adresyną! Perrašyti?",
    "Enter bookmark title" : "Įveskite adresyno įrašo pavadinimą",
    "Enter bookmark URL" : "Įveskite adresyno įrašo URL",
    "Folder" : "Aplankas",
    "Save" : "Įrašyti",
    "What's new?" : "Kas naujo?",
    "Failed to find existing bookmark" : "Nepavyko rasti esamo adresyno įrašo",
    "Failed to create bookmark" : "Nepavyko sukurti adresyno įrašo",
    "Failed to save bookmark" : "Nepavyko įrašyti adresyno įrašo",
    "Failed to move bookmark" : "Nepavyko perkelti adresyno įrašo",
    "Failed to delete bookmark" : "Nepavyko ištrinti adresyno įrašo",
    "Import successful" : "Importavimas pavyko",
    "Failed to rename tag" : "Nepavyko pervadinti žymos",
    "Failed to load tags" : "Nepavyko įkelti žymų",
    "Failed to load folders" : "Nepavyko įkelti aplankų",
    "Failed to delete folder" : "Nepavyko ištrinti aplanko",
    "Failed to create folder" : "Nepavyko sukurti aplanko",
    "Failed to move parts of selection" : "Nepavyko perkelti tam tikros žymėjimo dalies",
    "Failed to delete parts of selection" : "Nepavyko ištrinti tam tikros žymėjimo dalies",
    "Failed to fetch bookmarks." : "Nepavyko gauti adresyno įrašų.",
    "Failed to load setting {key}" : "Nepavyko įkelti nustatymo {key}",
    "Failed to update share {shareId}" : "Nepavyko atnaujinti viešinio {shareId}",
    "Failed to delete share {shareId}" : "Nepavyko ištrinti viešinio {shareId}",
    "Bookmarks feed" : "Adresyno įrašų kanalas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
